==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-cpuload/cpuload_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../../../lxqtcpuload.cpp" line="124"/>
        <source>CPU load %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>العامّ</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>إظهار النَّصّ</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Bottom up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Top down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="72"/>
        <source>Left to right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="73"/>
        <source>Right to left</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-cpuload/cpuload_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../../../lxqtcpuload.cpp" line="125"/>
        <source>CPU load %1%</source>
        <translation>حمل المعالج  %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>إعدادات حمل المعالج</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>عامّ</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>أظهر النّصّ</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>فترة التّحديث:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>ثا</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>اتّجاه الشّريط:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>عرض الشّريط:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>أسفل لأعلى</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>أعلى لأسفل</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>يسار إلى يمين</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>يمين إلى يسار</translation>
    </message>
</context>
</TS>
